import * as React from 'react';

import {
    Outlet,
    // useNavigate 
} from "react-router-dom";

import {
    AppBar, Box, CssBaseline, Divider, Drawer,
    IconButton, List, ListItem, ListItemButton, ListItemIcon, ListItemText,
    Toolbar, Typography, Container, Badge,
    MenuItem, Avatar,Menu
} from '@mui/material'

import {
    Mail as MailIcon, Notifications as NotificationsIcon,
    Menu as MenuIcon,
} from '@mui/icons-material'


import Footer from "../Components/Footer.js";
import ProfilePicture from '../Images/man.png';
// import useAuth from '../Auth/useAuth';


const drawerWidth = 240;

export function User(props) {

    const { window } = props;
    const [mobileOpen, setMobileOpen] = React.useState(false);

    const handleDrawerToggle = () => {
        setMobileOpen(!mobileOpen);
    };

    // const auth = useAuth();

    const drawer = (
        <div>
            <Toolbar />
            <Divider />
            <List>
                {['Mi perfil', 'Pruebas', 'Configuracion', 'Ayuda'].map((text, index) => (
                    <ListItem key={text} disablePadding>
                        <ListItemButton>
                            <ListItemIcon>
                                {index % 2 === 0 ? <MailIcon /> : <NotificationsIcon />}
                            </ListItemIcon>
                            <ListItemText primary={text} />
                        </ListItemButton>
                    </ListItem>
                ))}
            </List>
            <Divider />
            <List>
                {['All mail', 'Trash', 'Spam'].map((text, index) => (
                    <ListItem key={text} disablePadding>
                        <ListItemButton>
                            <ListItemIcon>
                                {index % 2 === 0 ? <MailIcon /> : <NotificationsIcon />}
                            </ListItemIcon>
                            <ListItemText primary={text} />
                        </ListItemButton>
                    </ListItem>
                ))}
            </List>
        </div>
    );

    const container = window !== undefined ? () => window().document.body : undefined;

    return (
        <Box sx={{ display: 'flex' }}>
            <CssBaseline />
            <AppBar
                position="fixed"
                sx={{
                    width: { sm: `calc(100% - ${drawerWidth}px)` },
                    ml: { sm: `${drawerWidth}px` },
                }}
            >
                <Toolbar>
                    <IconButton
                        color="inherit"
                        aria-label="open drawer"
                        edge="start"
                        onClick={handleDrawerToggle}
                        sx={{ mr: 2, display: { sm: 'none' } }}
                    >
                        <MenuIcon />
                    </IconButton>
                    <Typography variant="h6" noWrap component="div">
                        Pruebas Asignadas
                    </Typography>
                </Toolbar>

                <Box sx={{ display: { xs: 'none', md: 'flex' } }}>
                    <IconButton size="large" aria-label="show 4 new mails" color="inherit">
                        <Badge badgeContent={4} color="error">
                            <MailIcon style={{ color: '#212529' }} />
                        </Badge>
                    </IconButton>
                    <IconButton
                        size="large"
                        aria-label="show 17 new notifications"
                        color="inherit">
                        <Badge badgeContent={17} color="error">
                            <NotificationsIcon style={{ color: '#212529' }} />
                        </Badge>
                    </IconButton>


                    <IconButton
                        size="small"
                        edge="end"
                        aria-label="account of current user"
                        aria-haspopup="true"
                        aria-expanded={'true'}
                        color="inherit" >
                        <Avatar alt="profile picture" src={ProfilePicture} />
                    </IconButton>
                    <Menu
                        id="basic-menu"
                        MenuListProps={{ 'aria-labelledby': 'basic-button', }}>
                        <MenuItem >Mi Cuenta</MenuItem>
                        <MenuItem >Configuraciones</MenuItem>
                        <MenuItem >Cerrar Sesión</MenuItem>
                    </Menu>
                </Box>


            </AppBar>
            <Box
                component="nav"
                sx={{ width: { sm: drawerWidth }, flexShrink: { sm: 0 } }}
                aria-label="mailbox folders"
            >
                {/* The implementation can be swapped with js to avoid SEO duplication of links. */}
                <Drawer
                    container={container}
                    variant="temporary"
                    open={mobileOpen}
                    onClose={handleDrawerToggle}
                    ModalProps={{
                        keepMounted: true, // Better open performance on mobile.
                    }}
                    sx={{
                        display: { xs: 'block', sm: 'none' },
                        '& .MuiDrawer-paper': { boxSizing: 'border-box', width: drawerWidth },
                    }}
                >
                    {drawer}
                </Drawer>
                <Drawer
                    variant="permanent"
                    sx={{
                        display: { xs: 'none', sm: 'block' },
                        '& .MuiDrawer-paper': { boxSizing: 'border-box', width: drawerWidth },
                    }}
                    open
                >
                    {drawer}
                </Drawer>
            </Box>
            <Box
                component="main"
                sx={{ flexGrow: 1, p: 3, width: { sm: `calc(100% - ${drawerWidth}px)` } }} >

                <Container maxWidth="lg" sx={{ mt: 2, mb: 2 }}>
                    <Outlet />
                    <Footer />
                </Container>


            </Box>
        </Box>
    );
}

